@@ -12,7 +12,7 @@ async fn main() -> Result<(), Box<dyn Error>> {
 
     println!("Waiting for permit...");
     // should take about ten seconds to get a permit.
-    rate_limiter.acquire(10.0).await?;
+    rate_limiter.acquire(10.0).await;
     println!("I made it!");
     Ok(())
 }
