@@ -1,7 +1,8 @@
-#![deny(missing_docs, clippy::pedantic)]
-//! [![Documentation](https://docs.rs/leaky-bucket-lite/badge.svg)](https://docs.rs/leaky-bucket-lite)
-//! [![Crates](https://img.shields.io/crates/v/leaky-bucket-lite.svg)](https://crates.io/crates/leaky-bucket-lite)
-//! [![Actions Status](https://github.com/Gelbpunkt/leaky-bucket-lite/workflows/Rust/badge.svg)](https://github.com/Gelbpunkt/leaky-bucket-lite/actions)
+//! # leaky-bucket-lite
+//!
+//! [![docs badge][]][docs link]
+//! [![crates badge][]][crates link]
+//! [![actions badge][]][actions link]
 //!
 //! A token-based rate limiter based on the [leaky bucket] algorithm, mainly a lazy reimplementation of [udoprog's leaky-bucket] with less dependencies and overhead.
 //!
@@ -16,7 +17,7 @@
 //! Add the following to your `Cargo.toml`:
 //!
 //! ```toml
-//! leaky-bucket-lite = "0.3"
+//! leaky-bucket-lite = "0.4"
 //! ```
 //!
 //! ## Features
@@ -26,33 +27,53 @@
 //!   * [`sync_threadsafe::LeakyBucket`] (thread-safe, available via the `sync-threadsafe` feature)
 //!   * [`sync::LeakyBucket`] (not thread-safe, available via the `sync` feature).
 //!
-//! For potential performance increase with `sync-threadsafe` using [`parking_lot`]'s locking objects, enable the `parking-lot` feature.
+//! For potential performance increase with `sync-threadsafe` or `tokio` using [`parking_lot`]'s locking objects, enable the `parking_lot` feature.
 //!
 //! ## Example
 //!
 //! ```rust
 //! use leaky_bucket_lite::LeakyBucket;
-//! use std::{error::Error, time::Duration};
+//! use std::time::Duration;
 //!
 //! #[tokio::main]
-//! async fn main() -> Result<(), Box<dyn Error>> {
+//! async fn main() {
 //!     let rate_limiter = LeakyBucket::builder()
 //!         .max(5.0)
 //!         .tokens(0.0)
 //!         .refill_interval(Duration::from_secs(1))
 //!         .refill_amount(1.0)
 //!         .build();
+//!
 //!     println!("Waiting for permit...");
 //!     // should take about 5 seconds to acquire.
-//!     rate_limiter.acquire(5.0).await?;
+//!     rate_limiter.acquire(5.0).await;
 //!     println!("I made it!");
-//!     Ok(())
 //! }
 //! ```
 //!
+//! [actions badge]: https://github.com/Gelbpunkt/leaky-bucket-lite/workflows/Rust/badge.svg
+//! [actions link]: https://github.com/Gelbpunkt/leaky-bucket-lite/actions
+//! [crates badge]: https://img.shields.io/crates/v/leaky-bucket-lite.svg
+//! [crates link]: https://crates.io/crates/leaky-bucket-lite
+//! [docs badge]: https://docs.rs/leaky-bucket-lite/badge.svg
+//! [docs link]: https://docs.rs/leaky-bucket-lite
 //! [leaky bucket]: https://en.wikipedia.org/wiki/Leaky_bucket
 //! [udoprog's leaky-bucket]: https://github.com/udoprog/leaky-bucket
 
+#![deny(
+    clippy::all,
+    clippy::missing_const_for_fn,
+    clippy::pedantic,
+    future_incompatible,
+    missing_docs,
+    nonstandard_style,
+    rust_2018_idioms,
+    rustdoc::broken_intra_doc_links,
+    unsafe_code,
+    unused,
+    warnings
+)]
+
 #[cfg(feature = "tokio")]
 mod tokio;
 #[cfg(feature = "tokio")]
